@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/env python3
 """
 FindImports is a script that processes Python module dependencies.  Currently
 it can be used for finding unused imports and graphing module dependencies
@@ -27,6 +27,7 @@ options:
   --duplicate           warn about duplicate imports
   --ignore-stdlib       ignore the imports of modules from the Python standard
                         library
+  -q, --quiet           suppress warnings
   -v, --verbose         print more information (currently only affects
                         --duplicate)
   -N, --noext           omit external dependencies
@@ -47,7 +48,7 @@ options:
                         it back
   -I FILE, --ignore FILE
                         ignore a file or directory; this option can be used
-                        multiple times. Default: ['venv']
+                        multiple times. Default: ['.*']
   -R PREFIX [PREFIX ...], --rmprefix PREFIX [PREFIX ...]
                         remove PREFIX from displayed node names. This
                         operation is applied last. Names that collapses to
@@ -100,6 +101,8 @@ Ave, Cambridge, MA 02139, USA.
 import argparse
 import ast
 import doctest
+import fnmatch
+import json
 import linecache
 import os
 import pickle
@@ -111,7 +114,7 @@ import zipfile
 from operator import attrgetter
 
 
-__version__ = '2.6.0'
+__version__ = '2.7.0'
 __author__ = 'Marius Gedminas <marius@gedmin.as>'
 __licence__ = 'MIT'
 __url__ = 'https://github.com/mgedmin/findimports'
@@ -551,6 +554,7 @@ class ModuleGraph(object):
     all_unused = False
     warn_about_duplicates = False
     verbose = False
+    quiet = False
     external_dependencies = True
     max_depth = None
 
@@ -567,7 +571,7 @@ class ModuleGraph(object):
         self._exts.append(sysconfig.get_config_var('EXT_SUFFIX'))
 
     def warn(self, about, message, *args):
-        if about in self._warned_about:
+        if self.quiet or about in self._warned_about:
             return
         if args:
             message = message % args
@@ -601,11 +605,12 @@ class ModuleGraph(object):
                 pathname, ignore_stdlib_modules, import_to_search_for)
 
     def filterIgnores(self, dirs, files, ignores):
-        for ignore in ignores:
-            if ignore in dirs:
-                dirs.remove(ignore)
-            if ignore in files:
-                files.remove(ignore)
+        dirs[:] = [
+            n for n in dirs if not any(fnmatch.fnmatch(n, p) for p in ignores)
+        ]
+        files[:] = [
+            n for n in files if not any(fnmatch.fnmatch(n, p) for p in ignores)
+        ]
 
     def writeCache(self, filename):
         """Write the graph to a cache file."""
@@ -1033,6 +1038,34 @@ class ModuleGraph(object):
         """Print a dependency graph in dot format."""
         print(self.constructDot(attributes=attributes))
 
+    def asJSON(self):
+        """Prepare dependency list as a JSON dictionary"""
+        if self.external_dependencies:
+            return {
+                module.label: sorted(module.imports)
+                for module in self.listModules()
+            }
+        else:
+            return {
+                module.label: sorted(
+                    modname
+                    for modname in module.imports
+                    if modname in self.modules
+                )
+                for module in self.listModules()
+            }
+
+    def printJSON(self):
+        """Print a dependency graph in JSON format."""
+        json.dump(
+            self.asJSON(),
+            sys.stdout,
+            sort_keys=True,
+            indent=2,
+            separators=(',', ': '),
+        )
+        print()  # json.dump() doesn't emit a newline
+
 
 def quote(s):
     """Quote a string for graphviz.
@@ -1066,6 +1099,9 @@ def main(argv=None):
                          dest='action', const='printDot',
                          help='print dependency graph in dot (graphviz)'
                               ' format')
+    actions.add_argument('-j', '--json', action='store_const',
+                         dest='action', const='printJSON',
+                         help='print dependency graph in JSON format')
     actions.add_argument('-n', '--names', action='store_const',
                          dest='action', const='printImportedNames',
                          help='print dependency graph with all imported names')
@@ -1088,6 +1124,9 @@ def main(argv=None):
                          dest='ignore_stdlib',
                          help="ignore the imports of modules from the Python"
                               " standard library")
+    options.add_argument('-q', '--quiet', action='store_true',
+                         help='suppress warnings'
+                              ' (does not affect -u or --duplicate)')
     options.add_argument('-v', '--verbose', action='store_true',
                          help='print more information (currently only affects'
                               ' --duplicate)')
@@ -1122,11 +1161,11 @@ def main(argv=None):
     options.add_argument('-I', '--ignore', metavar='FILE', action="append",
                          help="ignore a file or directory;"
                               " this option can be used multiple times."
-                              " Default: ['venv']")
+                              " Default: ['.*']")
     options.add_argument('-R', '--rmprefix', metavar="PREFIX", nargs="+",
-                         help="remove PREFIX from displayed node names. "
-                              "This operation is applied last. "
-                              "Names that collapses to nothing are removed.")
+                         help="remove PREFIX from displayed node names."
+                              " This operation is applied last."
+                              " Names that collapse to nothing are removed.")
     options.add_argument('-D', '--depth', type=int,
                          dest='max_depth',
                          help='import depth in ast tree. Default: no limit')
@@ -1137,6 +1176,8 @@ def main(argv=None):
         args = parser.parse_args(args=argv[1:] if argv else None)
         if args.condense_to_packages and args.condense_to_packages_externals:
             parser.error('only one of -p and -pE can be provided')
+        if args.collapse_cycles and (args.action == 'printImportedNames'):
+            parser.error('only one of -c and -n can be provided')
     except SystemExit as e:
         return e.code
 
@@ -1145,10 +1186,11 @@ def main(argv=None):
     g.all_unused = args.all_unused
     g.warn_about_duplicates = args.warn_about_duplicates
     g.verbose = args.verbose
+    g.quiet = args.quiet
     g.trackUnusedNames = (args.action == 'printUnusedImports')
     for fn in args.filenames:
         g.parsePathname(fn,
-                        ignores=args.ignore or ["venv"],
+                        ignores=args.ignore or [".*"],
                         ignore_stdlib_modules=args.ignore_stdlib,
                         import_to_search_for=args.import_to_search_for)
     if args.write_cache:
